@@ -23,111 +23,7 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Log: opalplugin.h,v $
- * Revision 1.6  2009/02/21 14:07:43  shorne
- * Updated with changes from Opal
- *
- * Revision 1.5  2007/11/06 17:45:38  shorne
- * Added h323pluslib definition
- *
- * Revision 1.4  2007/11/06 17:43:33  shorne
- * added i480 standard framesize
- *
- * Revision 1.3  2007/10/30 04:23:43  shorne
- * Corrections and Improvements for H.239 support
- *
- * Revision 1.2  2007/10/19 19:53:43  shorne
- * ported latest Video updates in OpenH323 committed after h323plus initial fork thanks
- *  Robert
- *
- * Revision 1.1  2007/08/20 20:19:53  shorne
- * Moved opalplugin.h to codec directory to be plugin compile compatible with Opal
- *
- * Revision 1.2  2007/08/20 19:13:28  shorne
- * Added Generic Capability support. Fixed Linux compile errors
- *
- * Revision 1.1  2007/08/06 20:50:50  shorne
- * First commit of h323plus
- *
- * Revision 1.10.2.5  2007/09/26 05:14:28  rjongbloed
- * Added some extra RTP magic numbers: min header size, max packet size etc
- *
- * Revision 1.10.2.4  2007/08/17 08:38:22  rjongbloed
- * Back ported OPAL meda options based plug ins and H.323 generic capabilties.
- *
- * Revision 1.10.2.3  2007/02/19 20:12:45  shorne
- * added H.239 support
- *
- * Revision 1.10.2.2  2007/02/19 14:19:36  shorne
- * Added H.239 OIDs
- *
- * Revision 1.10.2.1  2006/12/23 19:08:02  shorne
- * Plugin video codecs & sundry
- *
- * Revision 1.10  2006/05/16 11:26:06  shorne
- * Added more hid key input mask types
- *
- * Revision 1.9  2005/11/21 21:04:10  shorne
- * Added more HID input switches
- *
- * Revision 1.8  2005/08/23 08:13:06  shorne
- * Added HID plugin volume & LCD display support
- *
- * Revision 1.7  2005/07/03 13:54:23  shorne
- * Added Initial LID Plugin Support
- *
- * Revision 1.6  2005/06/07 03:22:22  csoutheren
- * Added patch 1198741 with support for plugin codecs with generic capabilities
- * Added patch 1198754 with support for setting quality level on audio codecs
- * Added patch 1198760 with GSM-AMR codec support
- * Many thanks to Richard van der Hoff for his work
- *
- * Revision 1.5  2004/12/20 23:30:20  csoutheren
- * Added plugin support for packet loss concealment frames
- *
- * Revision 1.4  2004/11/29 06:30:53  csoutheren
- * Added support for wideband codecs
- *
- * Revision 1.3  2004/05/18 22:26:28  csoutheren
- * Initial support for embedded codecs
- * Fixed problems with streamed codec support
- * Updates for abstract factory loading methods
- *
- * Revision 1.2  2004/05/09 14:44:36  csoutheren
- * Added support for streamed plugin audio codecs
- *
- * Revision 1.1  2004/04/09 12:25:25  csoutheren
- * Renamed from h323plugin.h
- *
- * Revision 1.2  2004/04/03 10:38:24  csoutheren
- * Added in initial cut at codec plugin code. Branches are for wimps :)
- *
- * Revision 1.1.2.1  2004/03/31 11:03:16  csoutheren
- * Initial public version
- *
- * Revision 1.8  2004/02/23 13:17:32  craigs
- * Fixed problems with codec interface functions
- *
- * Revision 1.7  2004/02/23 13:04:09  craigs
- * Removed warnings when compliing plugins
- *
- * Revision 1.6  2004/01/27 14:55:46  craigs
- * Implemented static linking of new codecs
- *
- * Revision 1.5  2004/01/23 05:21:15  craigs
- * Updated for changes to the codec plugin interface
- *
- * Revision 1.4  2004/01/09 11:27:46  craigs
- * Plugin codec audio now works :)
- *
- * Revision 1.3  2004/01/09 07:32:22  craigs
- * More fixes for capability problems
- *
- * Revision 1.2  2004/01/06 07:05:03  craigs
- * Changed to support plugin codecs
- *
- * Revision 1.1  2004/01/04 13:37:51  craigs
- * Implementation of codec plugins
+ * $Id $
  *
  *
  */
@@ -142,8 +38,7 @@ extern "C" {
 #include <time.h>
 
 // indicator the this is h323plus version of the plugin codec
-// Most unfortunate!
-#define h323pluslib    1  
+#define h323pluslib          1 
 
 #ifdef _MSC_VER
 #pragma warning(disable:4201)
@@ -229,6 +124,7 @@ enum PluginCodec_Flags {
   PluginCodec_MediaTypeVideo         = 0x0001,
   PluginCodec_MediaTypeAudioStreamed = 0x0002,
   PluginCodec_MediaTypeFax           = 0x0003,
+  PluginCodec_MediaTypeExtended      = 0x0005,
 
   PluginCodec_InputTypeMask          = 0x0010,
   PluginCodec_InputTypeRaw           = 0x0000,
@@ -256,6 +152,7 @@ enum PluginCodec_Flags {
 
   PluginCodec_MediaExtensionMask     = 0x0400,
   PluginCodec_MediaTypeExtVideo      = 0x0400,
+  PluginCodec_MediaTypeH239          = 0x0401,
 
   PluginCodec_ComfortNoiseMask       = 0x0800,
   PluginCodec_ComfortNoise           = 0x0800,
@@ -276,9 +173,12 @@ enum PluginCodec_CoderFlags {
 };
 
 enum PluginCodec_ReturnCoderFlags {
-  PluginCodec_ReturnCoderLastFrame     = 1,    // indicates when video codec returns last data for frame
-  PluginCodec_ReturnCoderIFrame        = 2,    // indicates when video returns I frame
-  PluginCodec_ReturnCoderRequestIFrame = 4     // indicates when video decoder request I frame for resync
+  PluginCodec_ReturnCoderLastFrame      = 1,    // indicates when video codec returns last data for frame
+  PluginCodec_ReturnCoderIFrame         = 2,    // indicates when video returns I frame
+  PluginCodec_ReturnCoderRequestIFrame  = 4,    // indicates when video decoder request I frame for resync
+  PluginCodec_ReturnCoderBufferTooSmall = 8,    // indicates when output buffer is not large enough to receive
+                                                // the data, another call to get_output_data_size is required
+  PluginCodec_ReturnCoderMoreFrame      = 16    // indicates that the decoder need to output more frame
 };
 
 struct PluginCodec_Definition;
@@ -293,6 +193,24 @@ struct PluginCodec_Definition;
 #define PLUGINCODEC_CONTROL_TO_NORMALISED_OPTIONS "to_normalised_options"
 #define PLUGINCODEC_CONTROL_TO_CUSTOMISED_OPTIONS "to_customised_options"
 #define PLUGINCODEC_CONTROL_SET_INSTANCE_ID       "set_instance_id"
+#define PLUGINCODEC_CONTROL_SET_LOG_FUNCTION      "set_log_function"
+#define PLUGINCODEC_CONTROL_GET_STATISTICS        "get_statistics"
+#define PLUGINCODEC_CONTROL_TERMINATE_CODEC       "terminate_codec"
+#define PLUGINCODEC_CONTROL_CODEC_EVENT           "event_codec"
+#define PLUGINCODEC_CONTROL_FLOW_OPTIONS          "to_flowcontrol_options"
+#define PLUGINCODEC_CONTROL_SET_FORMAT_OPTIONS    "set_format_options"
+
+
+/* Log function, plug in gets a pointer to this function which allows
+   it to use the standard OPAL logging system. The function returns 0 if
+   no logging was performed due to the log level. Note if log == NULL
+   then this return state is all that happens, so this may be executed
+   first to prevent lengthy logs that would not result in any output. */
+typedef int (*PluginCodec_LogFunction)(unsigned level,
+                                       const char * file,
+                                       unsigned line,
+                                       const char * section,
+                                       const char * log);
 
 
 struct PluginCodec_ControlDefn {
@@ -372,7 +290,16 @@ struct PluginCodec_Option {
 #define PLUGINCODEC_OPTION_MAX_RX_FRAME_HEIGHT        "Max Rx Frame Height"
 #define PLUGINCODEC_OPTION_TEMPORAL_SPATIAL_TRADE_OFF "Temporal Spatial Trade Off"
 #define PLUGINCODEC_OPTION_TX_KEY_FRAME_PERIOD        "Tx Key Frame Period"
+#define PLUGINCODEC_OPTION_CUSTOM_FORMAT              "CustomFmt"
+#define PLUGINCODEC_OPTION_INPUT_FORMAT               "InputFmt"
+#define PLUGINCODEC_OPTION_EMPHASIS_SPEED             "Emphasis Speed"
+#define PLUGINCODEC_OPTION_MAX_PAYLOAD                "Max Payload Size"
 
+// Events
+#define PLUGINCODEC_EVENT_FASTUPDATE             "on_fast_update"
+#define PLUGINCODEC_EVENT_FLOWCONTROL            "on_flow_control"
+#define PLUGINCODEC_EVENT_LOSTPARTIAL            "on_lost_partial"
+#define PLUGINCODEC_EVENT_LOSTPICTURE            "on_lost_picture"
 
 // Full definition of the codec
 
@@ -599,6 +526,10 @@ enum {
 #define OpalPluginCodec_Identifer_AMR_NB          "0.0.8.245.1.1.9"
 #define OpalPluginCodec_Identifer_AMR_WB          "0.0.8.245.1.1.10"
 
+// G.722.1
+#define OpalPluginCodec_Identifer_G7221           "0.0.7.7221.1.0"
+#define OpalPluginCodec_Identifer_G7221ext        "0.0.7.7221.1.1.0"
+
 // G.722.2 (aka AMR-WB)
 #define OpalPluginCodec_Identifer_G7222           "0.0.7.7222.1.0"
 
@@ -618,9 +549,9 @@ enum {
 #define OpalPluginCodec_Identifer_MPEG4           "0.0.8.245.1.0.0"
 
 // Extended Video Capability (as defined in H.239)
-#define OpalPluginCodec_Identifer_H239            "0.0.8.239.1"
-#define OpalPluginCodec_Identifer_H239_Video      "0.0.8.239.2"
-#define OpalPluginCodec_Identifer_H239_Generic    "0.0.8.239.3"
+#define OpalPluginCodec_Identifer_H239                   "0.0.8.239.1.1"
+#define OpalPluginCodec_Identifer_H239_Video             "0.0.8.239.1.2"
+#define OpalPluginCodec_Identifer_H239_GenericMessage    "0.0.8.239.2"
 
 /////////////////
 //
@@ -632,6 +563,11 @@ enum {
 #define PLUGINCODEC_CIF_MPI       "CIF MPI"
 #define PLUGINCODEC_CIF4_MPI     "CIF4 MPI"
 #define PLUGINCODEC_CIF16_MPI   "CIF16 MPI"
+#define PLUGINCODEC_480P_MPI     "480 MPI"
+#define PLUGINCODEC_n720P_MPI    "n720 MPI"
+#define PLUGINCODEC_w720P_MPI     "w720 MPI"
+#define PLUGINCODEC_w1080P_MPI   "w1080 MPI"
+#define PLUGINCODEC_CUSTOM_MPI "Custom MPI"
 
 #define PLUGINCODEC_MPI_DISABLED 33
 
@@ -644,6 +580,8 @@ enum {
 #define H263_ANNEX_J "Annex J - Deblocking Filter"
 #define H263_ANNEX_T "Annex T - Modified Quantization"
 
+#define H263_EXPLICIT_MATCH "H263 Exact"
+
 #ifndef STRINGIZE
 #define __INTERNAL_STRINGIZE__(v) #v
 #define STRINGIZE(v) __INTERNAL_STRINGIZE__(v)
@@ -667,6 +605,8 @@ enum {
 #define PluginCodec_RTP_SetMarker(ptr, mark)       (((unsigned char*)(ptr))[1] = (((unsigned char*)(ptr))[1] & 0x7f) | (mark != 0 ? 0x80 : 0))
 #define PluginCodec_RTP_GetTimestamp(ptr)         ((((unsigned char*)(ptr))[4] << 24) | (((unsigned char*)(ptr))[5] << 16) | (((unsigned char*)(ptr))[6] << 8) | ((unsigned char*)(ptr))[7])
 #define PluginCodec_RTP_SetTimestamp(ptr, ts)     ((((unsigned char*)(ptr))[4] = ((ts) >> 24)),(((unsigned char*)(ptr))[5] = ((ts) >> 16)),(((unsigned char*)(ptr))[6] = ((ts) >> 8)),(((unsigned char*)(ptr))[7] = (ts)))
+#define PluginCodec_RTP_GetSequenceNumber(ptr)    ((((unsigned char*)(ptr))[2] << 8) | ((unsigned char*)(ptr))[3])
+#define PluginCodec_RTP_SetSequenceNumber(ptr, sn)((((unsigned char*)(ptr))[2] = ((sn) >> 8)),(((unsigned char*)(ptr))[3] = (sn)))
 
 
 /////////////////
@@ -707,6 +647,12 @@ struct PluginCodec_Video_SetFrameInfo {
 
 #ifdef OPAL_STATIC_CODEC
 
+#if _WIN32
+#pragma message("Building codec statically")
+#else
+#warning("Building codec statically")
+#endif
+
 #  undef PLUGIN_CODEC_DLL_API
 #  define PLUGIN_CODEC_DLL_API static
 #  define PLUGIN_CODEC_IMPLEMENT(name) \
@@ -719,7 +665,7 @@ struct PluginCodec_Definition * Opal_StaticCodec_##name##_GetCodecs(unsigned * p
 #  define PLUGIN_CODEC_IMPLEMENT_ALL(name, table, ver) \
 unsigned int Opal_StaticCodec_##name##_GetAPIVersion() \
 { return PWLIB_PLUGIN_API_VERSION; } \
-PLUGIN_CODEC_DLL_API struct PluginCodec_Definition * Opal_StaticCodec_##name##_GetCodecs(unsigned * count, unsigned version) \
+struct PluginCodec_Definition * Opal_StaticCodec_##name##_GetCodecs(unsigned * count, unsigned version) \
 { *count = sizeof(table)/sizeof(struct PluginCodec_Definition); return version < ver ? NULL : table; }
 
 
