@@ -23,7 +23,7 @@
  *
  * Contributor(s): Frbass Franz <franz.fuerbass@infonova.at>
  *
- * $Id: h235auth.h,v 1.22 2012/08/10 07:15:54 willamowius Exp $
+ * $Id: h235auth.h,v 1.31 2013/12/28 17:11:04 shorne Exp $
  *
  */
 
@@ -107,6 +107,12 @@ class H235Authenticator : public PObject
       PASN_Array & cryptoTokens
     );
 
+    virtual PBoolean PrepareTokens(
+      PASN_Array & clearTokens,
+      PASN_Array & cryptoTokens,
+      PINDEX max_cipherSize
+    );
+
     virtual H235_ClearToken * CreateClearToken();
     virtual H225_CryptoH323Token * CreateCryptoToken();
 
@@ -162,6 +168,12 @@ class H235Authenticator : public PObject
       PBoolean received
     ) const;
 
+    virtual PBoolean IsSecuredSignalPDU(
+      unsigned signalPDU,
+      PBoolean received,
+      PINDEX max_keyLength
+    ) const;
+
     virtual PBoolean IsActive() const;
 
     virtual void Enable(
@@ -256,7 +268,8 @@ PDECLARE_LIST(H235Authenticators, H235Authenticator)
     void PrepareSignalPDU(
       unsigned code,
       PASN_Array & clearTokens,
-      PASN_Array & cryptoTokens
+      PASN_Array & cryptoTokens,
+      PINDEX max_keyLength = P_MAX_INDEX
     ) const;
 
     H235Authenticator::ValidationResult ValidateSignalPDU(
@@ -284,6 +297,10 @@ PDECLARE_LIST(H235Authenticators, H235Authenticator)
     static void SetMaxCipherLength(PINDEX cipher);
     static PINDEX GetMaxCipherLength();
 
+    // maximum token length in bits
+    static void SetMaxTokenLength(PINDEX len);
+    static PINDEX GetMaxTokenLength();
+
     static PString & GetDHParameterFile();
     static void SetDHParameterFile(const PString & filePaths);
 
@@ -292,6 +309,7 @@ PDECLARE_LIST(H235Authenticators, H235Authenticator)
 
     static PINDEX m_encryptionPolicy;
     static PINDEX m_cipherLength;
+    static PINDEX m_maxTokenLength;
     static PString m_dhFile;
 #endif
 
@@ -301,23 +319,23 @@ class H235AuthenticatorInfo : public PObject
 {
     PCLASSINFO(H235AuthenticatorInfo, PObject);
 public:
-	H235AuthenticatorInfo(PString username,PString password,PBoolean ishashed);
-	H235AuthenticatorInfo(PSSLCertificate * cert);
-	PString UserName;
-	PString Password;
-	PBoolean isHashed;
-	PSSLCertificate * Certificate;
+    H235AuthenticatorInfo(PString username,PString password,PBoolean ishashed);
+    H235AuthenticatorInfo(PSSLCertificate * cert);
+    PString UserName;
+    PString Password;
+    PBoolean isHashed;
+    PSSLCertificate * Certificate;
 };
 
-PDECLARE_LIST(H235AuthenticatorList, H235AuthenticatorInfo)
+H323_DECLARELIST(H235AuthenticatorList, H235AuthenticatorInfo)
 #ifdef DOC_PLUS_PLUS
 {
 #endif
-	PBoolean HasUserName(PString UserName) const;
-	void LoadPassword(PString UserName, PString & pass) const;
-	void Add(PString username, PString password, PBoolean isHashed = FALSE);
-	PString PasswordEncrypt(const PString &clear) const;
-	PString PasswordDecrypt(const PString &encrypt) const;
+    PBoolean HasUserName(PString UserName) const;
+    void LoadPassword(PString UserName, PString & pass) const;
+    void Add(PString username, PString password, PBoolean isHashed = FALSE);
+    PString PasswordEncrypt(const PString &clear) const;
+    PString PasswordDecrypt(const PString &encrypt) const;
 };
 
 /** Dictionary of Addresses and Associated Security Info  */
@@ -376,7 +394,7 @@ class H235AuthSimpleMD5 : public H235Authenticator
 
 #if PTLIB_VER >= 2110 && defined(P_SSL)
 /// PFactory Loader
-typedef H235AuthSimpleMD5 H235_AuthenticatorMD5;
+typedef H235AuthSimpleMD5 H235AuthenticatorMD5;
 #ifndef _WIN32_WCE
   PPLUGIN_STATIC_LOAD(MD5,H235Authenticator);
 #endif
@@ -428,14 +446,14 @@ class H235AuthCAT : public H235Authenticator
 
 #if PTLIB_VER >= 2110 && defined(P_SSL)
 // PFactory Loader
-typedef H235AuthCAT H235_AuthenticatorCAT;
+typedef H235AuthCAT H235AuthenticatorCAT;
 #ifndef _WIN32_WCE
   PPLUGIN_STATIC_LOAD(CAT,H235Authenticator);
 #endif
 #endif
 
 
-#if P_SSL
+#if H323_SSL
 
 /** This class embodies the H.235 "base line" from H235.1.
 */
@@ -494,12 +512,20 @@ typedef H2351_Authenticator H235AuthProcedure1;  // Backwards interoperability
 
 //////////////////////////////////////////////////////////////////////////////
 
-typedef H2351_Authenticator H235_AuthenticatorStd1;
-#if PTLIB_VER >= 2110 && defined(P_SSL)
-#ifndef _WIN32_WCE
- PPLUGIN_STATIC_LOAD(Std1,H235Authenticator);
-#endif
-#endif
+#if PTLIB_VER >= 2130
+
+PCREATE_PLUGIN_DEVICE(H235Authenticator);
+#define H235SECURITY_EX(name,extra) \
+PCREATE_PLUGIN(name, H235Authenticator, H235Authenticator##name, PPlugin_H235Authenticator, \
+  virtual PStringArray GetDeviceNames(P_INT_PTR /*userData*/) const { return H235Authenticator##name::GetAuthenticatorNames(); } \
+  virtual bool  ValidateDeviceName(const PString & deviceName, int /*userData*/) const \
+    { return (deviceName == H235Authenticator##name::GetAuthenticatorNames()[0]); } \
+  virtual bool GetDeviceCapabilities(const PString & /*deviceName*/, void * caps) const \
+    { return H235Authenticator##name::GetAuthenticationCapabilities((H235Authenticator::Capabilities *)caps); } \
+extra)
+#define H235SECURITY(name) H235SECURITY_EX(name, )
+
+#else
 
 template <class className> class H235PluginServiceDescriptor : public PDevicePluginServiceDescriptor
 {
@@ -518,9 +544,10 @@ template <class className> class H235PluginServiceDescriptor : public PDevicePlu
 #endif
 };
 
-#define H235SECURITY(name)    \
-static H235PluginServiceDescriptor<H235_Authenticator##name> H235_Authenticator##name##_descriptor; \
-PCREATE_PLUGIN(name, H235Authenticator, &H235_Authenticator##name##_descriptor); \
+#define H235SECURITY(name) \
+static H235PluginServiceDescriptor<H235Authenticator##name> H235Authenticator##name##_descriptor; \
+PCREATE_PLUGIN(name, H235Authenticator, &H235Authenticator##name##_descriptor); 
+#endif
 
 #endif
 
