@@ -35,7 +35,7 @@
  *
  * Contributor(s): ______________________________________.
  *
- * $Id: h4601.h,v 1.34 2014/01/05 21:53:43 shorne Exp $
+ * $Id: h4601.h,v 1.38 2014/05/10 19:34:18 willamowius Exp $
  *
  *
  */
@@ -563,6 +563,8 @@ class H323EndPoint;
 class H323Connection;
 class H460_Feature : public H225_FeatureDescriptor
 {
+  PCLASSINFO(H460_Feature, H225_FeatureDescriptor);
+
   public:
   /**@name Construction */
   //@{
@@ -766,6 +768,10 @@ class H460_Feature : public H225_FeatureDescriptor
       */
     static int GetPurpose()    { return FeatureBaseAll; };
 
+    /** Get the feature purpose
+      */
+    virtual int GetFeaturePurpose()  { return GetPurpose(); } 
+
     /** Get the Feature Identifier
       */
     static PStringArray GetIdentifier() { return PStringArray("empty"); }
@@ -909,6 +915,10 @@ class H460_FeatureStd : public H460_Feature
 
   /**@name Parameter Control */
   //@{
+    /** Clone an item
+      */
+    PObject * Clone() const;
+
     /** Add item 
     */
     void Add(unsigned id);
@@ -953,6 +963,10 @@ class H460_FeatureNonStd : public H460_Feature
 
   /**@name Parameter Control */
   //@{
+    /** Clone an item
+      */
+    PObject * Clone() const;
+
     /** Add item 
     */
     void Add(const PString & id);
@@ -1000,6 +1014,10 @@ class H460_FeatureOID : public H460_Feature
 
   /**@name Parameter Control */
   //@{
+    /** Clone an item
+      */
+    PObject * Clone() const;
+
     /** Add item 
     */
     void Add(const PString & id);
@@ -1073,6 +1091,10 @@ class H460_FeatureSet : public PObject
      */
     H460_FeatureSet(const H225_ArrayOf_GenericData & generic);
 
+    /** Deconstructor
+      */
+    ~H460_FeatureSet();
+
     /** Derive new Feature Set based on this Feature Set ie Clone this FeatureSet
       */
     H460_FeatureSet * DeriveNewFeatureSet();
