@@ -493,6 +493,10 @@ class RTP_Session : public PObject
     class SenderReport : public PObject  {
         PCLASSINFO(SenderReport, PObject);
       public:
+        SenderReport() 
+        : sourceIdentifier(0), realTimestamp1970(0), 
+          rtpTimestamp(0), packetsSent(0), octetsSent(0) {}
+
         void PrintOn(ostream &) const;
 
         DWORD sourceIdentifier;
@@ -717,21 +721,21 @@ class RTP_Session : public PObject
 	/**
 	  * return the local Transport Address
 	  */
-	PString GetLocalTransportAddress() const { return localAddress; };
+	PString GetLocalTransportAddress() const { return locAddress; };
 
 	/**
 	  * return the remote Transport Address
 	  */
-	PString GetRemoteTransportAddress() const { return remoteAddress; };
+	PString GetRemoteTransportAddress() const { return remAddress; };
 
   //@}
 
   /**@name Functions added to RTP aggregator */
   //@{
-    virtual int GetDataSocketHandle() const
-    { return -1; }
-    virtual int GetControlSocketHandle() const
-    { return -1; }
+    virtual PINDEX GetDataSocketHandle() const
+    { return PINDEX(-1); }
+    virtual PINDEX GetControlSocketHandle() const
+    { return PINDEX(-1); }
   //@}
 
   protected:
@@ -759,8 +763,8 @@ class RTP_Session : public PObject
     WORD          lastSentSequenceNumber;
     WORD          expectedSequenceNumber;
     DWORD         lastSentTimestamp;
-    PTimeInterval lastSentPacketTime;
-    PTimeInterval lastReceivedPacketTime;
+    PInt64        lastSentPacketTime;
+    PInt64        lastReceivedPacketTime;
     WORD          lastRRSequenceNumber;
     PINDEX        consecutiveOutOfOrderPackets;
 
@@ -781,8 +785,8 @@ class RTP_Session : public PObject
     DWORD maximumJitterLevel;
 
 	// Socket information
-    PString localAddress;
-    PString remoteAddress;
+    PString locAddress;
+    PString remAddress;
 
     unsigned txStatisticsCount;
     unsigned rxStatisticsCount;
@@ -993,7 +997,8 @@ class RTP_UDP : public RTP_Session
       PHandleAggregator * aggregator, ///< RTP aggregator
 #endif
       unsigned id,                    ///<  Session ID for RTP channel
-      PBoolean remoteIsNat = FALSE        ///<  If TRUE, we have hints the remote endpoint is behind a NAT
+      PBoolean remoteIsNat = FALSE,   ///<  If TRUE, we have hints the remote endpoint is behind a NAT
+      PBoolean mediaTunneled = FALSE  ///<  Whether media is tunneled.
     );
 
     /// Destroy the RTP
@@ -1065,7 +1070,7 @@ class RTP_UDP : public RTP_Session
       BYTE ipTypeOfService,             ///<  Type of Service byte
 	  const H323Connection & connection, ///< Connection
 #ifdef P_STUN
-     PNatMethod * meth = NULL,          ///* Nat Method to use to create sockets (or NULL if no Method)
+      PNatMethod * meth = NULL,         ///< Nat Method to use to create sockets (or NULL if no Method)
 #else
       void * = NULL,                    ///<  STUN server to use createing sockets (or NULL if no STUN)
 #endif
@@ -1135,12 +1140,16 @@ class RTP_UDP : public RTP_Session
     /**Whether the remote has been detected as being behind NAT.
       */
     PBoolean IsRemoteNAT()  { return remoteIsNAT; }
+
+    /**Whether the remote has been detected as being behind NAT.
+      */
+    PBoolean IsMediaTunneled()  { return mediaIsTunneled; }
   //@}
 
-    int GetDataSocketHandle() const
+    PINDEX GetDataSocketHandle() const
     { return dataSocket != NULL ? dataSocket->GetHandle() : -1; }
 
-    int GetControlSocketHandle() const
+    PINDEX GetControlSocketHandle() const
     { return controlSocket != NULL ? controlSocket->GetHandle() : -1; }
 
   protected:
@@ -1173,6 +1182,8 @@ class RTP_UDP : public RTP_Session
 
     PBoolean remoteIsNAT;
     unsigned successiveWrongAddresses;
+
+    PBoolean mediaIsTunneled;
 };
 
 
